;+
;  tt01_crib
;
; Purpose: demonstrates the use of the tt01 procedure.  This procedure
; is tplot based version of the Tsyganenko 2001 magnetic fields model
;
; Notes: Haje Korth's IDL/Geopack DLM must be installed for this
;        to work
;
; $LastChangedBy: pcruce $
; $LastChangedDate: 2008-01-18 16:41:51 -0800 (Fri, 18 Jan 2008) $
; $LastChangedRevision: 2303 $
; $URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/idl_socware/trunk/external/IDL_GEOPACK/t01/tt01_crib.pro $
;-

timespan, '2007-03-23'

;load state data

thm_load_state, probe = 'b', coord = 'gsm'

;calculate model field

;example values were taken from Tsyganenko's papers, they don't

;reflect the actual conditions at this time

tt01, 'thb_state_pos',pdyn=2.0D,dsti=-30.0D,yimf=0.0D,zimf=-5.0D,$
g1=6.0D,g2=10.0D

;load fgm data for comparison

thm_load_fgm, probe = 'b', coord = 'gsm'

tplot_names

tplot, ['thb_state_pos_bt01', 'thb_fgs_gsm']

stop

;you can also generate g values using a built in geopack function

;the arguments are solar wind velocity(km/s) interplanetary magnetic

;field y component(nT) interplanetary magnetic field z component(nT)

;if you pass in N length arrays for each of the arguments it will

;produce an Nx2 length output

geopack_getg,350,0,-5,g

tt01, 'thb_state_pos',pdyn=2.0D,dsti=-30.0D,yimf=0.0D,zimf=-5.0D,g1=g[$

0,0],g2=g[0,1]

;load fgm data for comparison

thm_load_fgm, probe = 'b', coord = 'gsm'

tplot_names

tplot, ['thb_state_pos_bt01', 'thb_fgs_gsm']

;now translate magnetometer data into model aligned coordinates

;first we make the transformation matrix

fac_matrix_make, 'thb_state_pos_bt01', other_dim = 'Xgse', newname = $

'mod_mat'

;then we rotate

tvector_rotate, 'mod_mat', 'thb_fgs_gsm'

tplot_names

;model field, measured field, measured field in model coordinates

tplot, ['thb_state_pos_bt01', 'thb_fgs_gsm', 'thb_fgs_gsm_rot']

stop

;now substract model from the fgs data

;first interpolate the values onto the same grid

tinterpol_mxn,'thb_state_pos_bt01','thb_fgs_gsm',newname='mod_interp'

;now subtract

dif_data,'thb_fgs_gsm','mod_interp',newname='fgs_dif'

;set it up so model and fgm data are on the same plot

get_data,'mod_interp',data=d1

get_data,'thb_fgs_gsm',data=d2,dlimits=dl

d = {x:d1.x,y:[[d1.y],[double(d2.y)]],v:d1.v}

str_element,/add_replace,dl,'colors',[dl.colors,dl.colors]

str_element,/add_replace,dl,'labels',[dl.labels,dl.labels]

store_data,'mod_fgm',data=d,dlimits=dl

ylim,'fgs_dif',-400,1000

;to reset to autoscaling on the y axis type

;ylim,'fgs_dif',/default

;now plot

tplot,['mod_fgm','fgs_dif']

tlimit,'2007-03-23/18:03:00','2007-03-23/17:48:05'

stop

;the ace & wind read procedures use the current tlimit to figure out

;what data range to read

;here is wind data parameter generation

tlimit,/full

istp_init,local_data_dir='~/data/'

wi_mfi_load

wi_3dp_load

cotrans,'wi_h0_mfi_B3GSE','wi_b3gsm',/GSE2GSM

get_tsy_params,2.0D,time_double('2007-03-23/12:00:00'),'wi_b3gsm',$

'wi_3dp_ion_density','wi_3dp_ion_vel','T01'

tt01, 'thb_state_pos',parmod='t01_par'

tplot, ['thb_state_pos_bt01', 'thb_fgs_gsm']

stop


;the ace files below must be downloaded independently from the url

;below

;  http://www.srl.caltech.edu/ACE/ASC/level2/index.html

;they are too big to fit in the distribution

;You should download the mag 16 second and the solar wind 64 second

;files that span the 23 of march 2007

;if you got the correct files they will match the names below


load_ace_mag,filenames='mag_data_16sec_2369.hdf'

load_ace_swepam,filenames='swepam_data_ion_2369.hdf'

;load_ace_mag loads data in gse coords

cotrans,'ace_mag_Bgse','ace_mag_Bgsm',/GSE2GSM

get_tsy_params,2.0D,time_double('2007-03-23/12:00:00'),'ace_mag_Bgsm',$

'ace_swepam_Np','ace_swepam_Vp','T01'

tt01, 'thb_state_pos',parmod='t01_par'

tplot, ['thb_state_pos_bt01', 'thb_fgs_gsm']

end
