;+
;NAME:
; high_pass_filter
;PURPOSE:
; subtracts running average from a data array
;CALLING SEQUENCE:
; y = high_pass_filter(array, time_array, dt)
;INPUT:
; array = a data array
; time_array = a time array (in units of seconds)
; dt = the averaging time (in seconds)
;OUTPUT:
; y = the data array where at each point an average of the data for
; the previous dt has been subtracted.
;HISTORY:
; 14-jan-2008, jmm, jimm@ssl.berkeley.edu
; 06-feb-2008, teq, teq@ssl.berkeley.edu
;
;$LastChangedBy$
;$LastChangedDate$
;$LastChangedRevision$
;$URL$
;-

function high_pass_filter, array, time_array, dt
	;
	;; Declaring variable as -1 for later check
	;
  out_array = -1
	;
	;; determine number of rows in input array
	;; Note: this is a tplot array, reversed from
	;; idl array
	;
  n =  n_elements(array[*, 0])
	;
	;; Make sure time values exist for each entry
	;
  If(n_elements(time_array) Ne n) Then Begin
    message, /info, 'Array mismatch'
    return,  out_array
  Endif
	;
	;; Now declare output array
	;
  out_array = array & out_array[*] = 0
	;
	;; Produces array of values, the first being the dimension of the array
	;; which will later be used as a check
	;
  sz = size(array)
	;
	;; This for loop will take us through the full array of values
	;
  For j = 0l, n-1 Do Begin
		;
		;; Get subscripts of group to take running average over
		;; nss is the number values returned
		; 
    ss = where(time_array Lt time_array[j] And $
               time_array Ge time_array[j]-dt, nss)
		;
		;; Check if subscripts available
		;
    If(nss Gt 0) Then Begin
      If(sz[0] Eq 2) Then Begin
        avgj = total(array[ss, *], 1)/nss
        out_array[j, *] = array[j, *]-avgj
      Endif Else If(sz[0] Eq 1) Then Begin
        avgj = total(array[ss])/nss
        out_array[j] = array[j]-avgj
      Endif
    Endif
  Endfor
  Return, out_array
End
      
      
