;+
;PROCEDURE:  istp_init
;PURPOSE:    Initializes system variables for ISTP data.  Can be called from idl_startup to set
;            custom locations.
;

;
;HISTORY
; Written by Davin Larson
;
;$LastChangedBy: pcruce $
;$LastChangedDate: 2008-01-18 16:20:11 -0800 (Fri, 18 Jan 2008) $
;$LastChangedRevision: 2300 $
;$URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/ssl_general/trunk/missions/wind/istp_init.pro $
;-
pro istp_init, reset=reset, local_data_dir=local_data_dir, remote_data_dir=remote_data_dir

defsysv,'!istp',exists=exists
if not keyword_set(exists) then begin

   defsysv,'!istp',  file_retrieve(/structure_format)
endif

if keyword_set(reset) then !istp.init=0

if !istp.init ne 0 then return


!istp.remote_data_dir = 'http://cdaweb.gsfc.nasa.gov/istp_public/data/'
!istp.use_wget= getenv('username') eq 'davin'

caching = 1

if !version.os_family  eq 'Windows' then begin
   if CACHing then begin
      ;;-->   Location of local cache for WINDOWS
      ;;      Edit the following line to point to a writeable directory.
      if file_test('E:/data/istp/',/direc) then !istp.local_data_dir = 'E:/data/istp/'  $
      else  !istp.local_data_dir = 'C:/data/istp/'
      !istp.no_download = 0
   endif else begin
      ;;-->   Mount point of master data directory for WINDOWS
      ;;      E.g. At SSL, justice runs a read-only Samba server which
      ;;      provides direct access to //sprg.ssl.berkeley.edu/data/themis
      !istp.local_data_dir = '\\justice\data\istp/'
      !istp.no_download = 1
   endelse
   
endif 

if !version.os_family eq 'unix' then begin
   
   if caching then begin
      ;;-->  Location of local cache on your laptop for UNIX (or Mac)
      ;;     OR for desktops remote from SSL, this could be edited to
      ;;     point to a shared data area where many users can download
      ;;     data from the master data server.
      !istp.local_data_dir = '/disks/data/istp/'
      !istp.no_download = 0
   endif else begin
      ;;-->  Location of NFS mount point of master data directory.
      !istp.local_data_dir = '/disks/data/istp/'
      !istp.no_download = 1
   endelse

endif

if keyword_set(local_data_dir) then  $
   !istp.local_data_dir = local_data_dir

!istp.file_mode = '666'o         ; Allows other users to overwrite outdated files on shared directories
!istp.init = 1

printdat,/values,!istp,varname='!istp

end

