;+
;Procedure: WI_3DP_LOAD
;
;Purpose:  Loads WIND 3DP data
;
;keywords:
;   TRANGE= (Optional) Time range of interest  (2 element array).
;   /VERBOSE : set to output some useful info
;Example:
;   wi_3dp_load
;Notes:
;  This routine is still in development.
; Author: Davin Larson
;
; $LastChangedBy: davin-win $
; $LastChangedDate: 2007-09-21 11:55:54 -0700 (Fri, 21 Sep 2007) $
; $LastChangedRevision: 1611 $
; $URL $
;-
pro wi_3dp_load,type,files=files,trange=trange,verbose=verbose,downloadonly=downloadonly, $
      varformat=varformat,datatype=datatype, $
      addmaster=addmaster,data_source=data_source,tplotnames=tn,source=source

if not keyword_set(datatype) then datatype = 'k0'

istp_init
if not keyword_set(source) then source = !istp
    masterfile=''


if datatype eq 'k0'  then begin
    pathformat = 'wind/3dp/YYYY/wi_k0_3dp_YYYYMMDD_v0?.cdf'
    if not keyword_set(varformat) then  varformat = 'ion_density ion_vel ion_temp'
endif

if datatype eq 'pm'  then begin
    pathformat = 'wind/3dp_pm/YYYY/wi_pm_3dp_YYYYMMDD_v03.cdf'
    mstr_source = source
    mstr_source.remote_data_dir +=  'OLD_MASTERS/'
    mstr_source.local_data_dir  +=   'wind/3dp_pm/0000/'
;    masterfile = file_retrieve(_extra = mstr_source,'wi_pm_3dp_00000000_v01.cdf')
    if not keyword_set(varformat) then varformat = '?_* TIME'
endif


relpathnames = file_dailynames(file_format=pathformat,trange=trange,addmaster=addmaster)

files = [masterfile,file_retrieve(relpathnames, _extra=source,/last_version)]

if keyword_set(downloadonly) then return

cdf2tplot,file=files,varformat=varformat,verbose=verbose,prefix='wi_3dp_' ,tplotnames=tn    ; load data into tplot variables

; Set options for specific variables

options,/def,strfilter(tn,'wi_3dp_ion_vel',delim=' ') , colors='bgr', labels=['x','y','z']   ; set colors for the vector quantities
;options,/def,strfilter(tn,'wi_mfi_BGSEc') , ytitle = 'WIND!CB (nT)'

dprint,dlevel=3,'tplotnames: ',tn


end
