;+
;Purpose:
;Generates fgm overview plots for a given date
;this includes one day long plot and 4 1/4 day plots
;It stores these plots in the current directory
;
;Arguments:
;       date: the date for which the plots will be generated
;
;       directory(optional): an optional output directory
; 
;       device(optional):switch to 'z' device for cron plotting
;
; $LastChangedBy: jimm $
; $LastChangedDate: 2007-12-20 16:18:02 -0800 (Thu, 20 Dec 2007) $
; $LastChangedRevision: 2217 $
; $URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/thmsoc/trunk/idl/themis/common/thm_fgm_overviews.pro $
;-

pro thm_fgm_overviews,date,directory=directory,device=device,nopng=nopng,dont_delete_data=dont_delete_data

probe_list = ['a','b','c','d','e']

;clean slate
If(not keyword_set(dont_delete_data)) Then del_data,'*'

if not keyword_set(date) then begin
    message,/continue,'Date must be set to generate fgm overview plots'
    return
endif

date2 = time_string(date)

if keyword_set(directory) then dir=directory else dir='./'

if keyword_set(device) then set_plot,device

;tplot_options,'lazy_ytitle',0  ; prevent auto formatting on ytitle (namely having carrage returns at underscores)

timespan,date2,1,/day

year=string(strmid(date2,0,4))
month=string(strmid(date2,5,2))
day=string(strmid(date2,8,2))

thm_load_state,/get_sup

var_string1 = ''
var_string2 = ''

;Load all of the data, create sample rate bar
for i = 0L,n_elements(probe_list)-1L do begin
    sc = probe_list[i]
    sample_rate_var = thm_sample_rate_bar(date, 1, sc)
    thm_load_fgm, probe = sc, coord = 'gse' ;level 2 data has a suffix
;check for existence of data, if it is not there, try L1
    If(is_string(tnames('th'+sc+'_fgl_gse')) Eq 0) Then $
      thm_load_fgm, probe = sc, coord = 'gse', suff = '_gse', level = 'l1'
    thm_load_fit, probe = sc, coord = 'gse', suff = '_gse';level 1 is default
    sc = probe_list[i]          ;load routines can change this to an array
    var_string1 += 'th'+sc+'_fgs_gse '
    var_string2 += ' sample_rate_'+sc + ' th'+sc+'_fgl_gse '
;Adjust titles
    options, 'th'+sc+'_fgs_gse', 'ytitle', 'th'+sc+'_fgs_gse'
    options, 'th'+sc+'_fgl_gse', 'ytitle', 'th'+sc+'_fgl_gse'
;kill units in ytitles
    options, 'th'+sc+'_fgs_gse', 'ysubtitle', ''
    options, 'th'+sc+'_fgl_gse', 'ysubtitle', ''
endfor

var_string = var_string1 + ' ' + var_string2

;set colors
!p.background=255.
!p.color=0.
time_stamp,/off
loadct2,43
!p.charsize=0.8

tplot_options,'xmargin',[16,8]
ylim,'*',-100.,100.


If(Not keyword_set(nopng)) Then Begin
  tplot, var_string, title = 'TH-A,B,C,D,E, FGS, FGL [nT]'
  makepng, dir+'/thm_tohban_fgm_'+year+month+day+'_0024', /no_expose

  tplot, trange = [time_double(date2), time_double(date2)+3600.*6.]
  makepng, dir+'/thm_tohban_fgm_'+year+month+day+'_0006', /no_expose

  tplot, trange = [time_double(date2)+3600.*6, time_double(date2)+3600.*12.]
  makepng, dir+'/thm_tohban_fgm_'+year+month+day+'_0612', /no_expose

  tplot, trange = [time_double(date2)+3600.*12, time_double(date2)+3600.*18.]
  makepng, dir+'/thm_tohban_fgm_'+year+month+day+'_1218', /no_expose

  tplot, trange = [time_double(date2)+3600.*18, time_double(date2)+3600.*24.]
  makepng, dir+'/thm_tohban_fgm_'+year+month+day+'_1824', /no_expose
Endif Else Begin
  tplot, var_string, title = 'TH-A,B,C,D,E, FGS, FGL'
Endelse  

end
