pro spinmodel_post_process,sname=sname,filetype=filetype,datatype=datatype,$
  suffix=suffix,coord=coord,level=level,verbose=verbose,$
  tplotnames=tplotnames,progobj=progobj,_extra=_extra

common spinmodel_common,tha_sm_ptr, thb_sm_ptr, thc_sm_ptr,$
                        thd_sm_ptr, the_sm_ptr, thf_sm_ptr

if (n_elements(tha_sm_ptr) EQ 0) then begin
   tha_sm_ptr = ptr_new({spinmodel, probe:'a', capacity: 0L, lastseg:-1L,$
       index_n: 0L, index_t: 0L, segs_ptr: ptr_new() })
endif

if (n_elements(thb_sm_ptr) EQ 0) then begin
   thb_sm_ptr = ptr_new({spinmodel, probe:'b', capacity: 0L, lastseg:-1L,$
       index_n: 0L, index_t: 0L, segs_ptr: ptr_new() })
endif

if (n_elements(thc_sm_ptr) EQ 0) then begin
   thc_sm_ptr = ptr_new({spinmodel, probe:'c', capacity: 0L, lastseg:-1L,$
       index_n: 0L, index_t: 0L, segs_ptr: ptr_new() })
endif

if (n_elements(thd_sm_ptr) EQ 0) then begin
   thd_sm_ptr = ptr_new({spinmodel, probe:'d', capacity: 0L, lastseg:-1L,$
       index_n: 0L, index_t: 0L, segs_ptr: ptr_new() })
endif

if (n_elements(the_sm_ptr) EQ 0) then begin
   the_sm_ptr = ptr_new({spinmodel, probe:'e', capacity: 0L, lastseg:-1L,$
       index_n: 0L, index_t: 0L, segs_ptr: ptr_new() })
endif

if (n_elements(thf_sm_ptr) EQ 0) then begin
   thf_sm_ptr = ptr_new({spinmodel, probe:'f', capacity: 0L, lastseg:-1L,$
       index_n: 0L, index_t: 0L, segs_ptr: ptr_new() })
endif

if (n_elements(tplotnames) NE 7) then begin
   message,'Some or all required tplot variables were not found.',/continue
endif

case sname of
'a': mptr=tha_sm_ptr
'b': mptr=thb_sm_ptr
'c': mptr=thc_sm_ptr
'd': mptr=thd_sm_ptr
'e': mptr=the_sm_ptr
'f': mptr=thf_sm_ptr
else: begin
        message,'Unrecognized sname value: sname'
      end
endcase

if (ptr_valid((*mptr).segs_ptr) GT 0) then begin
   ptr_free,(*mptr).segs_ptr
endif

(*mptr).lastseg = -1L
(*mptr).capacity = 0L
(*mptr).index_n = 0L
(*mptr).index_t = 0L
(*mptr).probe = sname

;
; Extract data from tplot variables
prefix='th' + sname + '_spin_'
spinper_var=prefix + 'spinper'
time_var=prefix + 'time'
tend_var=prefix + 'tend'
c_var=prefix + 'c'
nspins_var=prefix + 'nspins'
npts_var=prefix + 'npts'
maxgap_var=prefix + 'maxgap'
phaserr_var=prefix + 'phaserr'

get_data,tend_var,tstart,tend
get_data,spinper_var,dummy,spinper
get_data,c_var,dummy,c
get_data,nspins_var,dummy,nspins
get_data,npts_var,dummy,npts
get_data,maxgap_var,dummy,maxgap
get_data,phaserr_var,dummy,phaserr

;help,tstart
;help,tend
;help,spinper
;help,c
;help,nspins
;help,npts
;help,maxgap

; Determine number of segments to make.  

seg_count=n_elements(tstart)

; get_data always returns at least one element
if (seg_count LE 1) then begin
  mymsg='No data for probe ' + sname
  message,mymsg,/continue
  return
endif


; Seams may require insertion of additional segments

shifted_array=tstart[1:seg_count-1]
seams=where(shifted_array NE tend)
seamcount = n_elements(seams)
;print,seamcount,' seams found.'
rec_count=seg_count
seg_count = seg_count + seamcount
(*mptr).capacity = seg_count
;for i = 0L,seamcount-1L,1L do begin
;  print,FORMAT='(F20.8, F20.8, E20.6)',tstart[seams[i]+1],tend[seams[i]],$
;        tstart[seams[i]+1]-tend[seams[i]]
;endfor

; Make segment array

segs = replicate({spinmodel_segment, t1:0.0D, t2:0.0D, c1:0L, c2:0L,$
          b:120.0D, c:0.0D, npts:0L, maxgap:0.0D, phaserr:0.0D},$
       seg_count)

(*mptr).segs_ptr = ptr_new(segs)

for i = 0L,rec_count-1L,1L do begin
   nextseg={spinmodel_segment,t1:tstart[i], t2:tend[i], c1:0L, c2:nspins[i],$
        b:360.0D/spinper[i], c:c[i], npts:npts[i], maxgap: maxgap[i],$
        phaserr:phaserr[i]}
   spinmodel_addseg,mptr,nextseg
endfor
end
